==> exsp-gen-5.0.1.tgz: package/readME.md <==
# exsp-gen , help to generate boilerplate

Create a robust Node.js backend REST API boilerplate integrated seamlessly with MongoDB. This package offers a comprehensive foundation for swiftly developing RESTful APIs. It includes a collection of pre-configured components, aiding in rapid setup and deployment. Streamline your backend development process with intuitive folder structures, standardized error handling, authentication middleware, database integration, and endpoint scaffolding. Simplify API creation with this boilerplate, equipped with essential tools and configurations, enabling developers to focus on application logic. Kickstart your Node.js backend project effortlessly, ensuring scalability, security, and maintainability in every API endpoint.

# Installation

```bash
  npm install -g exsp-gen
  exsp-gen --version
```

## How use It

```bash
  exsp-gen create-node-app --name test --db mysql
```

```bash
  exsp-gen create-node-app --name test --db mongodb
```

```bash
  exsp-gen create-node-app --name test --db psql
```

- **--name** - Identifies the project name.
- **--db** - Identifies the database type.

## Available Services

- create-node-app: Used to create a Node.js project.

```bash
  exsp-gen create-node-app --name test --db mysql
```

```bash
  exsp-gen create-node-app --name test --db mongodb
```

```bash
  exsp-gen create-node-app --name test --db psql
```

- create-python-app: Used to create a Python project.
- create-react-app: Used to create a React project.

## Features New Added

- Login/SignUp
- GET Profile
- UPDATE Profile
- Upload Profile with S3 Bucker
- Pagination
- CRUD Operations
- Upload File
- S3 Bucket
- Sequelize ORM
- Sequelize CLI
- Mongodb

### COMING SOON ...

- Python Repid Setup
- React Repid Setup
- Socket.io - Using socket.io You can create chat app
  - Single Chat
  - Group chat

## Authors

- [@vivekmethew](https://github.com/VivekMethew)

# Hi, I'm Vivek Methew! 👋

### YouTube Channel

**SUBSCRIBE** to our **YouTube** channel!

- [@vivek dev](https://youtube.com/@vivek__dev?si=ve5H-pTtWtPabumw)

  Don't forget to **like and comment** on our videos to let us know what you think!

==> exsp-gen-5.0.3.tgz: package/readME.md <==
# exsp-gen , help to generate boilerplate

Create a robust Node.js backend REST API boilerplate integrated seamlessly with MongoDB. This package offers a comprehensive foundation for swiftly developing RESTful APIs. It includes a collection of pre-configured components, aiding in rapid setup and deployment. Streamline your backend development process with intuitive folder structures, standardized error handling, authentication middleware, database integration, and endpoint scaffolding. Simplify API creation with this boilerplate, equipped with essential tools and configurations, enabling developers to focus on application logic. Kickstart your Node.js backend project effortlessly, ensuring scalability, security, and maintainability in every API endpoint.

# Installation

```bash
  npm install -g exsp-gen
  exsp-gen --version
```

## How use It

```bash
  exsp-gen create-node-app --name test --db mysql
```

```bash
  exsp-gen create-node-app --name test --db mongodb
```

```bash
  exsp-gen create-node-app --name test --db psql
```

- **--name** - Identifies the project name.
- **--db** - Identifies the database type.

## Available Services

- **create-node-app**: Used to create a Node.js project.

```bash
  exsp-gen create-node-app --name test --db mysql
```

```bash
  exsp-gen create-node-app --name test --db mongodb
```

```bash
  exsp-gen create-node-app --name test --db psql
```

- **create-python-app**: Used to create a Python project.
- **create-react-app**: Used to create a React project.

## Features New Added

- Login/SignUp
- GET Profile
- UPDATE Profile
- Upload Profile with S3 Bucker
- Pagination
- CRUD Operations
- Upload File
- S3 Bucket
- Sequelize ORM
- Sequelize CLI
- Mongodb

### COMING SOON ...

- **Python** Repid Setup
- **React** Repid Setup
- **Socket.io** - Using socket.io You can create chat app
  - Single Chat
  - Group chat

## Authors

- [@vivekmethew](https://github.com/VivekMethew)

# Hi, I'm Vivek Methew! 👋

### YouTube Channel

**SUBSCRIBE** to our **YouTube** channel!

- [@vivek dev](https://youtube.com/@vivek__dev?si=ve5H-pTtWtPabumw)

  Don't forget to **like and comment** on our videos to let us know what you think!
